@@ -284,7 +284,7 @@ simulate_formula.network <- function(object, nsim=1, seed=NULL,
     if(missing(dynamic) && "lasttoggle" %in% list.network.attributes(basis)) warning("For dynamic simulation in ", sQuote("tergm"), " you must pass ", sQuote("dynamic=TRUE"), ".  Attempting ", sQuote("ergm"), " simulation instead...")
 
     mc <- match.call()
-    mc[[1]] <- ergm_simulate_formula_network
+    mc[[1]] <- ergm::.simulate_formula.network
     return(eval.parent(mc))
   }
 
@@ -483,7 +483,7 @@ simulate_formula.networkDynamic <- function(object, nsim=1, seed=NULL,
     if(missing(dynamic)) warning("For dynamic simulation in ", sQuote("tergm"), " you must pass ", sQuote("dynamic=TRUE"), ".  Attempting ", sQuote("ergm"), " simulation instead...")
 
     mc <- match.call()
-    mc[[1]] <- ergm_simulate_formula_network
+    mc[[1]] <- ergm::.simulate_formula.network
     return(eval.parent(mc))
   }
 
